@@ -316,9 +316,6 @@
          ,x0 (rol32 ,x0 5)
          ,x2 (rol32 ,x2 22)))
 
-(defmacro sosemanuk-mkname (prefix n)
-  `,(read-from-string (format nil "~a~d" prefix n)))
-
 (defclass sosemanuk (stream-cipher)
   ((state :accessor sosemanuk-state
           :initform (make-array 10 :element-type '(unsigned-byte 32))
@@ -367,20 +364,20 @@
           w7 (ub32ref/le buffer 28))
 
     (macrolet ((sks (s o0 o1 o2 o3 d0 d1 d2 d3)
-                 `(let ((r0 (sosemanuk-mkname "w" ,o0))
-                        (r1 (sosemanuk-mkname "w" ,o1))
-                        (r2 (sosemanuk-mkname "w" ,o2))
-                        (r3 (sosemanuk-mkname "w" ,o3))
+                 `(let ((r0 ,(symbolicate '#:w o0))
+                        (r1 ,(symbolicate '#:w o1))
+                        (r2 ,(symbolicate '#:w o2))
+                        (r3 ,(symbolicate '#:w o3))
                         (r4 0))
                     (declare (type (unsigned-byte 32) r0 r1 r2 r3))
                     (,s r0 r1 r2 r3 r4)
-                    (setf (aref subkeys i) (sosemanuk-mkname "r" ,d0))
+                    (setf (aref subkeys i) ,(symbolicate '#:r d0))
                     (incf i)
-                    (setf (aref subkeys i) (sosemanuk-mkname "r" ,d1))
+                    (setf (aref subkeys i) ,(symbolicate '#:r d1))
                     (incf i)
-                    (setf (aref subkeys i) (sosemanuk-mkname "r" ,d2))
+                    (setf (aref subkeys i) ,(symbolicate '#:r d2))
                     (incf i)
-                    (setf (aref subkeys i) (sosemanuk-mkname "r" ,d3))
+                    (setf (aref subkeys i) ,(symbolicate '#:r d3))
                     (incf i)))
                (sks0 ()
                  `(sks sosemanuk-s0 4 5 6 7 1 4 2 0))
@@ -470,27 +467,27 @@
                (fss (zc s i0 i1 i2 i3 i4 o0 o1 o2 o3)
                  `(progn
                     (ka ,zc
-                        (sosemanuk-mkname "r" ,i0)
-                        (sosemanuk-mkname "r" ,i1)
-                        (sosemanuk-mkname "r" ,i2)
-                        (sosemanuk-mkname "r" ,i3))
-                    (,s (sosemanuk-mkname "r" ,i0)
-                        (sosemanuk-mkname "r" ,i1)
-                        (sosemanuk-mkname "r" ,i2)
-                        (sosemanuk-mkname "r" ,i3)
-                        (sosemanuk-mkname "r" ,i4))
-                    (sosemanuk-lt (sosemanuk-mkname "r" ,o0)
-                                  (sosemanuk-mkname "r" ,o1)
-                                  (sosemanuk-mkname "r" ,o2)
-                                  (sosemanuk-mkname "r" ,o3))))
+                        ,(symbolicate '#:r i0)
+                        ,(symbolicate '#:r i1)
+                        ,(symbolicate '#:r i2)
+                        ,(symbolicate '#:r i3))
+                    (,s ,(symbolicate '#:r i0)
+                        ,(symbolicate '#:r i1)
+                        ,(symbolicate '#:r i2)
+                        ,(symbolicate '#:r i3)
+                        ,(symbolicate '#:r i4))
+                    (sosemanuk-lt ,(symbolicate '#:r o0)
+                                  ,(symbolicate '#:r o1)
+                                  ,(symbolicate '#:r o2)
+                                  ,(symbolicate '#:r o3))))
                (fsf (zc s i0 i1 i2 i3 i4 o0 o1 o2 o3)
                  `(progn
                     (fss ,zc ,s ,i0 ,i1 ,i2 ,i3 ,i4 ,o0 ,o1 ,o2 ,o3)
                     (ka ,(+ zc 4)
-                        (sosemanuk-mkname "r" ,o0)
-                        (sosemanuk-mkname "r" ,o1)
-                        (sosemanuk-mkname "r" ,o2)
-                        (sosemanuk-mkname "r" ,o3)))))
+                        ,(symbolicate '#:r o0)
+                        ,(symbolicate '#:r o1)
+                        ,(symbolicate '#:r o2)
+                        ,(symbolicate '#:r o3)))))
       (fss 0 sosemanuk-s0 0 1 2 3 4 1 4 2 0)
       (fss 4 sosemanuk-s1 1 4 2 0 3 2 1 0 4)
       (fss 8 sosemanuk-s2 2 1 0 4 3 0 4 1 3)
@@ -570,18 +567,18 @@
                  `(let ((tt 0)
                         (or1 0))
                     (declare (type (unsigned-byte 32) tt or1))
-                    (setf tt (xmux r1 (sosemanuk-mkname "s" ,x1) (sosemanuk-mkname "s" ,x8))
+                    (setf tt (xmux r1 ,(symbolicate '#:s x1) ,(symbolicate '#:s x8))
                           or1 r1
                           r1 (mod32+ r2 tt)
                           tt (mod32* or1 #x54655307)
                           r2 (rol32 tt 7))))
                (lru (x0 x3 x9 dd)
-                 `(setf ,dd (sosemanuk-mkname "s" ,x0)
-                        (sosemanuk-mkname "s" ,x0) (logxor (mul-a (sosemanuk-mkname "s" ,x0))
-                                                           (mul-g (sosemanuk-mkname "s" ,x3))
-                                                           (sosemanuk-mkname "s" ,x9))))
+                 `(setf ,dd ,(symbolicate '#:s x0)
+                        ,(symbolicate '#:s x0) (logxor (mul-a ,(symbolicate '#:s x0))
+                                                       (mul-g ,(symbolicate '#:s x3))
+                                                       ,(symbolicate '#:s x9))))
                (cc1 (x9 ee)
-                 `(setf ,ee (logxor (mod32+ (sosemanuk-mkname "s" ,x9) r1) r2)))
+                 `(setf ,ee (logxor (mod32+ ,(symbolicate '#:s x9) r1) r2)))
                (stp (x0 x1 x3 x8 x9 dd ee)
                  `(progn
                     (fsm ,x1 ,x8)
@@ -590,10 +587,10 @@
                (srd (s x0 x1 x2 x3 ooff)
                  `(progn
                     (,s u0 u1 u2 u3 u4)
-                    (setf (ub32ref/le buffer ,ooff) (logxor (sosemanuk-mkname "u" ,x0) v0)
-                          (ub32ref/le buffer ,(+ ooff 4)) (logxor (sosemanuk-mkname "u" ,x1) v1)
-                          (ub32ref/le buffer ,(+ ooff 8)) (logxor (sosemanuk-mkname "u" ,x2) v2)
-                          (ub32ref/le buffer ,(+ ooff 12)) (logxor (sosemanuk-mkname "u" ,x3) v3)))))
+                    (setf (ub32ref/le buffer ,ooff) (logxor ,(symbolicate '#:u x0) v0)
+                          (ub32ref/le buffer ,(+ ooff 4)) (logxor ,(symbolicate '#:u x1) v1)
+                          (ub32ref/le buffer ,(+ ooff 8)) (logxor ,(symbolicate '#:u x2) v2)
+                          (ub32ref/le buffer ,(+ ooff 12)) (logxor ,(symbolicate '#:u x3) v3)))))
       (stp 0 1 3 8 9 v0 u0)
       (stp 1 2 4 9 0 v1 u1)
       (stp 2 3 5 0 1 v2 u2)
