@@ -109,10 +109,10 @@
 ;;; macros for "mid-level" functions
 
 (defmacro define-digest-registers ((digest-name &key (endian :big) (size 4) (digest-registers nil)) &rest registers)
-  (let* ((struct-name (read-from-string (format nil "~A-~A" digest-name '#:regs)))
-         (constructor (read-from-string (format nil "~A-~A" '#:initial struct-name)))
-         (copier (read-from-string (format nil "%~A-~A" '#:copy struct-name)))
-         (digest-fun (read-from-string (format nil "~A~A" digest-name '#:regs-digest)))
+  (let* ((struct-name (symbolicate digest-name '#:-regs))
+         (constructor (symbolicate '#:initial- struct-name))
+         (copier      (symbolicate '#:copy- struct-name))
+         (digest-fun  (symbolicate digest-name '#:-regs-digest))
          (register-bit-size (* size 8))
          (digest-size (* size (or digest-registers
                                   (length registers))))
@@ -135,10 +135,11 @@
                   (type (integer 0 ,(- array-dimension-limit digest-size)) start)
                   ,(burn-baby-burn))
          ,(let ((inlined-unpacking
-                 `(setf ,@(loop for (reg value) in registers
-                             for index from 0 below digest-size by size
-                             nconc `((,ref-fun buffer (+ start ,index))
-                                     (,(read-from-string (format nil "~A-~A-~A" digest-name '#:regs reg)) regs))))))
+                  `(setf ,@(loop for (reg value) in registers
+                                 for index from 0 below digest-size by size
+                                 nconc `((,ref-fun buffer (+ start ,index))
+                                         (,(symbolicate digest-name '#:-regs- reg)
+                                          regs))))))
                (cond
                  #+(and sbcl :little-endian)
                  ((eq endian :little)
@@ -175,7 +176,7 @@
 (defmacro define-digest-finalizer (specs &body body)
   (let* ((single-digest-p (not (consp (car specs))))
          (specs (if single-digest-p (list specs) specs))
-         (inner-fun-name (read-from-string (format nil "%~A-~A-~A" '#:finalize (caar specs) '#:state))))
+         (inner-fun-name (symbolicate '#:finalize- (caar specs) '#:-state)))
     (destructuring-bind (maybe-doc-string &rest rest) body
       (let ((primary-digest (caar specs)))
         `(defmethod produce-digest ((state ,primary-digest)
@@ -192,11 +193,10 @@
                     (macrolet ((finalize-registers (state regs)
                                  (declare (ignorable state))
                                  (let ((clauses
-                                        (loop for (digest-name digest-length) in ',specs
-                                              collect `(,digest-name
-                                                         (,(read-from-string (format nil "~A~A"
-                                                                           digest-name '#:regs-digest))
-                                                                   ,regs digest digest-start)))))
+                                         (loop for (digest-name digest-length) in ',specs
+                                               collect `(,digest-name
+                                                         (,(symbolicate digest-name '#:-regs-digest)
+                                                          ,regs digest digest-start)))))
                                    (if ,single-digest-p
                                        (second (first clauses))
                                        (list* 'etypecase state
@@ -367,14 +367,10 @@
   (update-digest-from-stream digester stream
                              :buffer buffer :start start :end end))
 
-(defun optimized-maker-name (name)
-  (let ((*package* (find-package :ironclad)))
-    ;; Ironclad gets compiled with *PRINT-CASE* set to :UPCASE; ensure
-    ;; that names we return match what got compiled.n
-    (intern (format nil "%~A-~A-~A"
-                    (symbol-name '#:make)
-                    (symbol-name name)
-                    (symbol-name '#:digest)))))
+(eval-when (:compile-toplevel :load-toplevel)
+  (defun optimized-maker-name (name)
+    (let ((*package* (find-package :ironclad)))
+      (symbolicate '#:%make- name '#:-digest))))
 
 (defmacro defdigest (name &key digest-length block-length)
   (let ((optimized-maker-name (optimized-maker-name name)))
