@@ -12,13 +12,13 @@
 (defun list-all-macs ()
   (loop for symbol being each external-symbol of (find-package :ironclad)
         if (macp symbol)
-          collect symbol into macs
+          collect (intern (symbol-name symbol) :keyword) into macs
         finally (return (sort macs #'string<))))
 
 (defun mac-supported-p (name)
   "Return T if the mac NAME is a valid mac name."
   (and (symbolp name)
-       (not (null (macp name)))))
+       (not (null (macp (massage-symbol name))))))
 
 (defmacro defmac (name maker updater producer)
   `(progn
